@@ -626,6 +626,10 @@ impl<'a> Emitter<'a> {
                         if value.fract() == 0.0 {
                             return true;
                         }
+                        if span.is_dummy() {
+                            return false;
+                        }
+
                         // check if numeric literal is a decimal literal that was originally written
                         // with a dot
                         if let Ok(text) = self.cm.span_to_snippet(span) {
@@ -2499,15 +2503,19 @@ fn escape_without_source(v: &str, target: JscTarget, single_quote: bool) -> Stri
             }
 
             _ => {
-                let escaped = c.escape_unicode().to_string();
+                if target >= EsVersion::Es2015 {
+                    let escaped = c.escape_unicode().to_string();
 
-                if escaped.starts_with('\\') {
-                    buf.push_str("\\u");
-                    if escaped.len() == 8 {
-                        buf.push_str(&escaped[3..=6]);
-                    } else {
-                        buf.push_str(&escaped[2..]);
+                    if escaped.starts_with('\\') {
+                        buf.push_str("\\u");
+                        if escaped.len() == 8 {
+                            buf.push_str(&escaped[3..=6]);
+                        } else {
+                            buf.push_str(&escaped[2..]);
+                        }
                     }
+                } else {
+                    buf.push(c);
                 }
             }
         }
